@@ -226,7 +226,8 @@ def viperhpdeoptimize(vipertoken,host,port,consumefrom,produceto,companyname,con
     val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid))
     return val
 
-def viperhpdetraining(vipertoken,host,port,consumefrom,produceto,companyname,consumerid,producerid,hpdehost,partition=-1,modelruns=50,hpdeport=-999,offset=-1,islogistic=0,
+def viperhpdetraining(vipertoken,host,port,consumefrom,produceto,companyname,consumerid,producerid,hpdehost,partition=-1,modelruns=50,
+                      hpdeport=-999,offset=-1,islogistic=0,
                       brokerhost='',brokerport=9092,timeout=120,microserviceid=''):
 
     #reads the fieldnames and gets latest data from each stream (or fieldname)
